@@ -14,7 +14,7 @@ package Main;
 use File::FindLib 'lib';
 
 use Moose;
-use Carp::Always;
+#use Carp::Always;
 use Data::Dumper;
 
 extends 'Runner::Slurm';
